@@ -1,13 +1,13 @@
 package Net::DNS::DynDNS;
 
+use warnings;
+use strict;
 use LWP();
 use HTTP::Cookies();
 use HTTP::Headers();
 use Carp();
 use English qw(-no_match_vars);
-use warnings;
-use strict;
-our $VERSION = '0.998';
+our $VERSION = '0.9991';
 
 our @CARP_NOT = ('Net::DNS::DynDNS');
 sub DEFAULT_TIMEOUT                      { return 60 }
@@ -171,12 +171,14 @@ sub _parse_ip_address {
     }
     else {
         my $content = $response->content();
+        $content =~ s/\s*$//smx;
         if ( $content =~ /Can't\sconnect\sto\s$self->{check_ip}/xsm ) {
             Carp::croak("Failed to connect to '$check_ip_uri'");
         }
         else {
             Carp::croak(
-                "Failed to get a success type response from '$check_ip_uri'");
+"Failed to get a success type response from '$check_ip_uri':$content"
+            );
         }
     }
     return $ip_address;
@@ -399,7 +401,7 @@ sub _error {
         'dnserr' => 'DNS error encountered',
         '911'    => 'There is a problem or scheduled maintenance on our side',
     );
-    Carp::croak( $errors{$code} || "Unknown error:$code" );
+    Carp::croak( $errors{$code} || "Unknown error:$code:$content" );
 }
 
 sub update {
@@ -456,7 +458,13 @@ sub _parse_content {
           )
         {
             my ( $code, $additional ) = ( $1, $2 );
-            if ( ( $code eq 'good' ) || ( $code eq 'nochg' ) ) {
+            if (
+                   ( $code eq 'good' )
+                || ( $code eq 'nochg' )
+                || ( $code eq '200'
+                ) # used by http://www.changeip.com/accounts/knowledgebase.php?action=displayarticle&id=47
+              )
+            {
                 if ($result) {
                     if ( $result ne $additional ) {
                         Carp::croak(
